#

##

##

###

###

###

###

###

###

##

    	layers

    	base layer providers

    		https://www.maptiler.com/cloud/

    	drawing layers

    		slider
    			https://openlayers.org/en/latest/examples/layer-opacity.html

    		circles
    			https://openlayers.org/en/latest/examples/draw-shapes.html

    		freehand
    			https://openlayers.org/en/latest/examples/draw-freehand.html

    		snap to point
    			https://openlayers.org/en/latest/examples/snap.html

    		tracing
    			https://openlayers.org/en/latest/examples/tracing.html

    			https://openlayers.org/en/latest/examples/draw-and-modify-features.html

    			https://openlayers.org/en/latest/apidoc/module-ol_source_Vector-VectorSource.html

    			import { Vector as VectorLayer } from 'ol/layer.js';
    			import { Vector as VectorSource } from 'ol/source.js';

    			const vector_source = new VectorSource ();
    			const vector_layer = new VectorLayer ({
    				source: source,
    				style: {
    					'fill-color': 'rgba(255, 255, 255, 0.4)',
    					'stroke-color': '#ff50b3a6',
    					'stroke-width': 4,

    					'circle-radius': 7,
    					'circle-fill-color': '#ff50b3a6',
    					'circle-stroke-color': 'black',
    					'circle-stroke-width': 2,
    				},
    			});

    	important

    		Graticule:
    			https://openlayers.org/en/latest/examples/graticule.html

    		CartoDB:
    			https://openlayers.org/en/latest/examples/cartodb.html

    		Beauty:
    			https://openlayers.org/en/latest/examples/color-manipulation.html